# Part of the PsychoPy library
# Copyright (C) 2010 Jonathan Peirce
# Distributed under the terms of the GNU General Public License (GPL).

"""
placeholder for adding c (or ctypes) extensions to the linux PsychoPy
"""
def rush(value=True):    
    """Raise the priority of the current thread/process 
    NOT YET IMPLEMENTED ON posix (but you can use 
    > nice python ......
    
    """
    return False
  
  